==> vector_tile_renderer-2.0.1.tar.gz: lib/src/features/symbol_point_renderer.dart <==
import 'dart:ui';

import 'package:flutter/rendering.dart';
import 'package:vector_tile/vector_tile.dart';
import 'package:vector_tile/vector_tile_feature.dart';

import '../../vector_tile_renderer.dart';
import '../constants.dart';
import '../context.dart';
import '../logger.dart';
import '../themes/style.dart';
import 'feature_geometry.dart';
import 'feature_renderer.dart';
import 'text_abbreviator.dart';
import 'text_renderer.dart';

class SymbolPointRenderer extends FeatureRenderer {
  final Logger logger;
  final FeatureGeometry geometry;
  SymbolPointRenderer(this.logger) : geometry = FeatureGeometry(logger);

  @override
  void render(Context context, ThemeLayerType layerType, Style style,
      VectorTileLayer layer, VectorTileFeature feature) {
    final textPaint = style.textPaint;
    final textLayout = style.textLayout;
    if (textPaint == null || textLayout == null) {
      logger.warn(() => 'point does not have a text paint or layout');
      return;
    }
    final points = geometry.decodePoints(feature);
    if (points != null) {
      logger.log(() => 'rendering points');
      final text = textLayout.text(feature);
      if (text != null) {
        final abbreviated = TextAbbreviator().abbreviate(text);
        final textRenderer = TextRenderer(context, style, abbreviated);
        points.forEach((point) {
          points.forEach((point) {
            if (point.length < 2) {
              throw Exception('invalid point ${point.length}');
            }
            final x = (point[0] / layer.extent) * tileSize;
            final y = (point[1] / layer.extent) * tileSize;
            final box = textRenderer.labelBox(Offset(x, y), translated: true);
            if (box != null &&
                context.labelSpace.canOccupy(textRenderer.text, box)) {
              context.labelSpace.occupy(textRenderer.text, box);
              textRenderer.render(Offset(x, y));
            }
          });
        });
      } else {
        logger.warn(() => 'point with no text');
      }
    }
  }
}

==> vector_tile_renderer-2.0.2.tar.gz: lib/src/features/symbol_point_renderer.dart <==
import 'dart:ui';

import 'package:flutter/rendering.dart';
import 'package:vector_tile/vector_tile.dart';
import 'package:vector_tile/vector_tile_feature.dart';

import '../../vector_tile_renderer.dart';
import '../constants.dart';
import '../context.dart';
import '../logger.dart';
import '../themes/style.dart';
import 'feature_geometry.dart';
import 'feature_renderer.dart';
import 'text_abbreviator.dart';
import 'text_renderer.dart';

class SymbolPointRenderer extends FeatureRenderer {
  final Logger logger;
  final FeatureGeometry geometry;
  SymbolPointRenderer(this.logger) : geometry = FeatureGeometry(logger);

  @override
  void render(Context context, ThemeLayerType layerType, Style style,
      VectorTileLayer layer, VectorTileFeature feature) {
    final textPaint = style.textPaint;
    final textLayout = style.textLayout;
    if (textPaint == null || textLayout == null) {
      logger.warn(() => 'point does not have a text paint or layout');
      return;
    }
    final points = geometry.decodePoints(feature);
    if (points != null) {
      logger.log(() => 'rendering points');
      final text = textLayout.text(feature);
      final abbreviated =
          text == null ? null : TextAbbreviator().abbreviate(text);
      if (text != null &&
          context.labelSpace.canAccept(abbreviated) &&
          abbreviated != null) {
        final textRenderer = TextRenderer(context, style, abbreviated);
        points.forEach((point) {
          points.forEach((point) {
            if (point.length < 2) {
              throw Exception('invalid point ${point.length}');
            }
            final x = (point[0] / layer.extent) * tileSize;
            final y = (point[1] / layer.extent) * tileSize;
            final box = textRenderer.labelBox(Offset(x, y), translated: true);
            if (box != null &&
                context.labelSpace.canOccupy(textRenderer.text, box)) {
              context.labelSpace.occupy(textRenderer.text, box);
              textRenderer.render(Offset(x, y));
            }
          });
        });
      } else {
        logger.warn(() => 'point with no text');
      }
    }
  }
}
